aboutsummaryrefslogtreecommitdiffstats
path: root/LUFA/Drivers/Board/ATAVRUSBRF01
diff options
context:
space:
mode:
Diffstat (limited to 'LUFA/Drivers/Board/ATAVRUSBRF01')
-rw-r--r--LUFA/Drivers/Board/ATAVRUSBRF01/Buttons.h (renamed from LUFA/Drivers/Board/ATAVRUSBRF01/HWB.h)30
1 files changed, 17 insertions, 13 deletions
diff --git a/LUFA/Drivers/Board/ATAVRUSBRF01/HWB.h b/LUFA/Drivers/Board/ATAVRUSBRF01/Buttons.h
index 87426de16..29cc4e362 100644
--- a/LUFA/Drivers/Board/ATAVRUSBRF01/HWB.h
+++ b/LUFA/Drivers/Board/ATAVRUSBRF01/Buttons.h
@@ -30,14 +30,14 @@
/** \file
*
* Board specific HWB driver header for the ATAVRUSBRF01.
*
* \note This file should not be included directly. It is automatically included as needed by the HWB driver
* dispatch header located in LUFA/Drivers/Board/HWB.h.
*/
-#ifndef __HWB_ATAVRUSBRF01_H__
-#define __HWB_ATAVRUSBRF01_H__
+#ifndef __BUTTONS_ATAVRUSBRF01_H__
+#define __BUTTONS_ATAVRUSBRF01_H__
/* Includes: */
#include <avr/io.h>
@@ -51,23 +51,27 @@
#endif
/* Preprocessor Checks: */
#if !defined(INCLUDE_FROM_HWB_H)
#error Do not include this file directly. Include LUFA/Drivers/Board/HWB.h instead.
#endif
/* Public Interface - May be used in end-application: */
+ /* Macros: */
+ /** Button mask for the first button on the board. */
+ #define BUTTONS_BUTTON1 (1 << 7)
+
/* Inline Functions: */
#if !defined(__DOXYGEN__)
- static inline void HWB_Init(void)
+ static inline void Buttons_Init(void)
{
- DDRD &= ~(1 << 7);
- PORTD |= (1 << 7);
+ DDRD &= ~BUTTONS_BUTTON1;
+ PORTD |= BUTTONS_BUTTON1;
}
- static inline bool HWB_GetStatus(void) ATTR_WARN_UNUSED_RESULT;
- static inline bool HWB_GetStatus(void)
+ static inline uint8_t Buttons_GetStatus(void) ATTR_WARN_UNUSED_RESULT;
+ static inline uint8_t Buttons_GetStatus(void)
{
- return (!(PIND & (1 << 7)));
+ return ((PIND & BUTTONS_BUTTON1) ^ BUTTONS_BUTTON1);
}
#endif
@@ -30,14 +30,14 @@
/** \file
*
- * Board specific HWB driver header for the ATAVRUSBRF01.
+ * Board specific Buttons driver header for the ATAVRUSBRF01.
*
@@ -30,14 +30,14 @@
*
- * \note This file should not be included directly. It is automatically included as needed by the HWB driver
- * dispatch header located in LUFA/Drivers/Board/HWB.h.
+ * \note This file should not be included directly. It is automatically included as needed by the Buttons driver
+ * dispatch header located in LUFA/Drivers/Board/Buttons.h.
*/
@@ -51,23 +51,27 @@
#endif
/* Preprocessor Checks: */
- #if !defined(INCLUDE_FROM_HWB_H)
- #error Do not include this file directly. Include LUFA/Drivers/Board/HWB.h instead.
+ #if !defined(INCLUDE_FROM_BUTTONS_H)
+ #error Do not include this file directly. Include LUFA/Drivers/Board/Buttons.h instead.
#endif
/* Public Interface - May be used in end-application: */